package com.mdd.admin.service.impl;

import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Assert;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.mdd.admin.service.IChannelOaReplyKeywordService;
import com.mdd.admin.validate.channel.ChannelRpKeywordValidate;
import com.mdd.admin.validate.commons.PageValidate;
import com.mdd.admin.vo.channel.ChannelRpKeywordVo;
import com.mdd.common.core.PageResult;
import com.mdd.common.entity.OfficialReply;
import com.mdd.common.mapper.OfficialReplyMapper;
import java.util.Arrays;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import javax.annotation.Resource;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

@Service
public class ChannelOaReplyKeywordServiceImpl implements IChannelOaReplyKeywordService {
   @Resource
   OfficialReplyMapper officialReplyMapper;

   public PageResult<ChannelRpKeywordVo> list(PageValidate pageValidate) {
      Integer pageNo = pageValidate.getPageNo();
      Integer pageSize = pageValidate.getPageSize();
      IPage<OfficialReply> iPage = this.officialReplyMapper.selectPage(new Page((long)pageNo, (long)pageSize), (Wrapper)((QueryWrapper)((QueryWrapper)(new QueryWrapper()).eq("reply_type", 2)).eq("is_delete", 0)).orderByDesc(Arrays.asList("sort", "id")));
      List<ChannelRpKeywordVo> list = new LinkedList();
      Iterator var6 = iPage.getRecords().iterator();

      while(var6.hasNext()) {
         OfficialReply officialReply = (OfficialReply)var6.next();
         ChannelRpKeywordVo vo = new ChannelRpKeywordVo();
         BeanUtils.copyProperties(officialReply, vo);
         list.add(vo);
      }

      return PageResult.iPageHandle(iPage.getTotal(), iPage.getCurrent(), iPage.getSize(), list);
   }

   public ChannelRpKeywordVo detail(Integer id) {
      OfficialReply officialReply = (OfficialReply)this.officialReplyMapper.selectOne((Wrapper)((QueryWrapper)((QueryWrapper)(new QueryWrapper()).eq("id", id)).eq("is_delete", 0)).last("limit 1"));
      Assert.notNull(officialReply, "数据不存在!", new Object[0]);
      ChannelRpKeywordVo vo = new ChannelRpKeywordVo();
      BeanUtils.copyProperties(officialReply, vo);
      return vo;
   }

   public void add(ChannelRpKeywordValidate keywordValidate) {
      OfficialReply officialReply = new OfficialReply();
      officialReply.setReplyType(2);
      officialReply.setName(keywordValidate.getName());
      officialReply.setContent(keywordValidate.getContent());
      officialReply.setContentType(keywordValidate.getContentType());
      officialReply.setStatus(keywordValidate.getStatus());
      officialReply.setKeyword(keywordValidate.getKeyword());
      officialReply.setSort(keywordValidate.getSort());
      officialReply.setMatchingType(keywordValidate.getMatchingType());
      officialReply.setCreateTime(System.currentTimeMillis() / 1000L);
      officialReply.setUpdateTime(System.currentTimeMillis() / 1000L);
      this.officialReplyMapper.insert(officialReply);
   }

   @Transactional
   public void edit(ChannelRpKeywordValidate keywordValidate) {
      OfficialReply officialReply = (OfficialReply)this.officialReplyMapper.selectOne((Wrapper)((QueryWrapper)((QueryWrapper)(new QueryWrapper()).eq("id", keywordValidate.getId())).eq("is_delete", 0)).last("limit 1"));
      Assert.notNull(officialReply, "关键词回复数据不存在!", new Object[0]);
      officialReply.setReplyType(2);
      officialReply.setId(keywordValidate.getId());
      officialReply.setName(keywordValidate.getName());
      officialReply.setContent(keywordValidate.getContent());
      officialReply.setContentType(keywordValidate.getContentType());
      officialReply.setStatus(keywordValidate.getStatus());
      officialReply.setKeyword(keywordValidate.getKeyword());
      officialReply.setMatchingType(keywordValidate.getMatchingType());
      officialReply.setSort(keywordValidate.getSort());
      officialReply.setUpdateTime(System.currentTimeMillis() / 1000L);
      this.officialReplyMapper.updateById(officialReply);
   }

   public void del(Integer id) {
      OfficialReply officialReply = (OfficialReply)this.officialReplyMapper.selectOne((Wrapper)((QueryWrapper)((QueryWrapper)(new QueryWrapper()).eq("id", id)).eq("is_delete", 0)).last("limit 1"));
      Assert.notNull(officialReply, "关键词回复数据不存在了!", new Object[0]);
      officialReply.setIsDelete(1);
      officialReply.setDeleteTime(System.currentTimeMillis() / 1000L);
      this.officialReplyMapper.updateById(officialReply);
   }

   public void status(Integer id) {
      OfficialReply officialReply = (OfficialReply)this.officialReplyMapper.selectOne((Wrapper)((QueryWrapper)((QueryWrapper)(new QueryWrapper()).eq("is_delete", 0)).eq("id", id)).last("limit 1"));
      Assert.notNull(officialReply, "关键词回复数据不存在!!", new Object[0]);
      int status = officialReply.getStatus() == 1 ? 0 : 1;
      officialReply.setId(id);
      officialReply.setStatus(status);
      officialReply.setUpdateTime(System.currentTimeMillis() / 1000L);
      this.officialReplyMapper.updateById(officialReply);
   }
}
